@@ -1,7 +1,7 @@
 package App::tracepm;
 
-our $DATE = '2015-04-14'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-04-15'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -120,6 +120,19 @@ _
             pos => 1,
             greedy => 1,
         },
+        multiple_args => {
+            # XXX add args_rels: conflict with args
+            summary => 'A set of args, run script multiple times',
+            schema => ['array*' => of => ['array*' => of => 'str*']],
+            description => <<'_',
+
+An alternative to using `args`. Script will be run multiple times, each with a
+set of args from this.
+
+Can be used to reach multiple run pathways and trace more modules.
+
+_
+        },
         perl_version => {
             summary => 'Perl version, defaults to current running version',
             description => <<'_',
@@ -183,8 +196,8 @@ sub tracepm {
     my $add_fields_and_filter_1 = sub {
         my $r = shift;
         if ($args{detail} || defined($args{core})) {
-            require Module::CoreList;
-            my $is_core = Module::CoreList::is_core(
+            require Module::CoreList::More;
+            my $is_core = Module::CoreList::More->is_still_core(
                 $r->{module}, undef, $plver);
             return 0 if defined($args{core}) && ($args{core} xor $is_core);
             $r->{is_core} = $is_core;
@@ -219,11 +232,16 @@ sub tracepm {
         } else {
             # 'require' method
             $routine = sub {
-                system($^X,
-                       "-MApp::tracepm::Tracer=$outf",
-                       (map {"-M$_"} @{$args{use} // []}),
-                       $script, @{$args{args} // []},
-                   );
+                my @args_sets = $args{multiple_args} ?
+                    @{ $args{multiple_args} } : ($args{args});
+                local $App::tracepm::Tracer::APPEND_MODE = 1;
+                for my $args (@args_sets) {
+                    system($^X,
+                           "-MApp::tracepm::Tracer=$outf",
+                           (map {"-M$_"} @{$args{use} // []}),
+                           $script, @{$args // []},
+                       );
+                }
             };
         }
 
@@ -328,8 +346,8 @@ sub tracepm {
                         }
                     }
                     if ($args{recurse_exclude_core}) {
-                        require Module::CoreList;
-                        my $is_core = Module::CoreList::is_core(
+                        require Module::CoreList::More;
+                        my $is_core = Module::CoreList::More->is_still_core(
                             $mod, undef, $plver); # XXX use $v?
                         if ($is_core) {
                             $log->infof("Skipped recursing to %s: core module", $mod);
@@ -396,7 +414,7 @@ App::tracepm - Trace dependencies of your Perl script
 
 =head1 VERSION
 
-This document describes version 0.15 of App::tracepm (from Perl distribution App-tracepm), released on 2015-04-14.
+This document describes version 0.16 of App::tracepm (from Perl distribution App-tracepm), released on 2015-04-15.
 
 =head1 SYNOPSIS
 
@@ -472,6 +490,15 @@ faster.
 
 =back
 
+=item * B<multiple_args> => I<array[array[str]]>
+
+A set of args, run script multiple times.
+
+An alternative to using C<args>. Script will be run multiple times, each with a
+set of args from this.
+
+Can be used to reach multiple run pathways and trace more modules.
+
 =item * B<perl_version> => I<str>
 
 Perl version, defaults to current running version.
