@@ -1,7 +1,9 @@
 package App::tracepm::Tracer;
 
-our $DATE = '2015-04-14'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-04-15'; # DATE
+our $VERSION = '0.16'; # VERSION
+
+our $APPEND_MODE = 0;
 
 # saving CORE::GLOBAL::require doesn't work
 my $orig_require;
@@ -22,7 +24,7 @@ sub import {
     my $file = shift
         or die "Usage: use App::tracerpm::Tracer '/path/to/output'";
 
-    open my($fh), ">", $file or die "Can't open $file: $!";
+    open my($fh), ($APPEND_MODE?">>":">"), $file or die "Can't open $file: $!";
 
     #$orig_require = \&CORE::GLOBAL::require;
     *CORE::GLOBAL::require = sub {
@@ -61,7 +63,7 @@ App::tracepm::Tracer - Trace module require to file
 
 =head1 VERSION
 
-This document describes version 0.15 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2015-04-14.
+This document describes version 0.16 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2015-04-15.
 
 =head1 HOMEPAGE
 
